Data segment definition (sarpy.io.general.data_segment)
=======================================================

.. automodule:: sarpy.io.general.data_segment
    :members:
    :show-inheritance:
    :inherited-members:
